← Blender.Today
  • Published 4 Jun 2020

Will Blender be developing a Node for "data saving", for faster node calculations?

I am new, this may not be the area, but I had a thought that nodes are very slow in their calculations and take about 10 to 30 seconds to calculate on an average node set-up.

So, will Blender develop something like a node for the output that saves data to a temporary cache file that keeps data for the node tree, so when a socket noodle is changed, only that noodle is calculated and not the entire tree? Maybe it does this already, but to me it looks like it re-calculates the whole tree every time?

This is why I tend not to use large node set-ups for procedural shaders, but would do so if an output material node had tabs to save the "tree material data" without making a new material (as the new material saved is saved in a separate cache temporarily), - and a further additional tab on the output available on selection, for more saves. That can also be named on the node tabs of that output node.

Then I could go back to a previously saved state at the push of a tab on the output node with next to no waiting time for because the calculations are saved in the cache/temporary blend file.

I could also, if there was a "purge output node save data" option, and I had NOT used it -go back and use a "save state tab" to revert to another node tree saved set-up, create a new material copy, then swap the original back to its, saved first state selected, if it had a saved state I could use for a desired material later on after the creation of said original material "saved states".

Final production could also purge all unused mesh,node save data, materials, nodes and alike etc.

This could then be a very quick time saver for computers with under 16GB of RAM laptops etc, as this also affects Eevee screen space waiting for node calculations etc.

I am not sure if this is possible, but maybe it is only possible if nothing moves in the view? Or maybe it will work great. I just am a bit tired of waiting for node calculations every time I change a node-noodle from a socket and all I am doing is changing a gamma node to a hue node and the whole node tree remains the same.

Hopefully their is a person who knows how to sort this and improve the speed as I know next to zero about development programming etc, thanks for reading, and I hope this was useful to someone.

Maybe this has changed in 2.9, as I am on 2.82a still, as I'm still getting used to it after 2.81 etc.

djb3000
4 Jun 2020